.. image:: https://travis-ci.org/musevlt/mpdaf.svg?branch=master
  :target: https://travis-ci.org/musevlt/mpdaf

.. image:: https://codecov.io/gh/musevlt/mpdaf/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/musevlt/mpdaf

MPDAF, the *MUSE Python Data Analysis Framework*, is an open-source (BSD
licensed) Python package, developed and maintained by `CRAL
<https://cral.univ-lyon1.fr/>`_ and partially funded by the ERC advanced grant
339659-MUSICOS (see `Authors and Credits
<http://mpdaf.readthedocs.io/en/stable/credits.html>`_ for more details).  It
has been developed and used in the `MUSE Consortium
<http://muse-vlt.eu/science/>`_ for several years, and is available freely for
the community.

It provides tools to work with MUSE-specific data (raw data, pixel tables,
etc.), and with more general data like spectra, images and data cubes. Although
its main use is to work with MUSE data, it is also possible to use it with other
data, for example HST images.

MPDAF also provides MUSELET, a SExtractor-based tool to detect emission lines in
a datacube, and a format to gather all the information on a source in one FITS
file.

Bug reports, comments, and help with development are very welcome.

MPDAF 3.0 requires Python 3.5 or later.  It is the first version that supports
only Python 3. `Older versions <https://pypi.org/project/mpdaf/#history>`_ can
be installed for users that still need Python 2.

Links
-----

- `Documentation <http://mpdaf.readthedocs.io/en/stable/>`_.
- Source, issues and pull requests on
  `Github <https://github.com/musevlt/mpdaf/>`_ and on a
  `Gitlab <https://git-cral.univ-lyon1.fr/MUSE/mpdaf>`_ instance.
- Releases on `PyPI <https://pypi.org/project/mpdaf/>`_.
- `Mailing list <mpdaf-support@osulistes.univ-lyon1.fr>`_ to get help or
  discuss issues.

Reporting Issues
----------------

If you have found a bug in MPDAF please `create an issue on Github
<https://github.com/musevlt/mpdaf/issues/new>`_.

Citing
------

MPDAF can be cited with the `ASCL <http://ascl.net/1611.003>`_ reference (`ADS
<http://adsabs.harvard.edu/abs/2016ascl.soft11003B>`__, `BibTeX
<http://adsabs.harvard.edu/cgi-bin/nph-bib_query?bibcode=2016ascl.soft11003B&data_type=BIBTEX&db_key=AST&nocookieset=1>`__),
and was also presented at ADASS XXVI, for which the proceedings is on the
`arXiv <https://arxiv.org/abs/1710.03554>`_ (`ADS
<http://adsabs.harvard.edu/abs/2017arXiv171003554P>`__, `BibTeX
<http://adsabs.harvard.edu/cgi-bin/nph-bib_query?bibcode=2017arXiv171003554P&data_type=BIBTEX&db_key=PRE&nocookieset=1>`__).
